@@ -54,18 +54,21 @@ sub find {
   if (ref $vals[0] eq 'HASH') {
     $query = $vals[0];
   } elsif (@pk == @vals) {
-    my $ret = ($class->search_literal($class->_ident_cond, @vals, $attrs))[0];
+    $query = {};
+    @{$query}{@pk} = @vals;
+    #my $ret = ($class->search_literal($class->_ident_cond, @vals, $attrs))[0];
     #warn "$class: ".join(', ', %{$ret->{_column_data}});
-    return $ret;
+    #return $ret;
   } else {
     $query = {@vals};
   }
   $class->throw( "Can't find unless all primary keys are specified" )
     unless (keys %$query >= @pk); # If we check 'em we run afoul of uc/lc
                                   # column names etc. Not sure what to do yet
-  my $ret = ($class->search($query))[0];
-  #warn "$class: ".join(', ', %{$ret->{_column_data}});
-  return $ret;
+  #return $class->search($query)->next;
+  my @cols = $class->_select_columns;
+  my @row = $class->storage->select_single($class->_table_name, \@cols, $query);
+  return (@row ? $class->_row_to_object(\@cols, \@row) : ());
 }
 
 sub discard_changes {
